﻿using UnityEngine;
using System.Collections;
using System;

public class AudioManager : MonoBehaviour
{
    [Header("Variables References")]
    public AudioClip[] scenesMusics;

    public static AudioManager Instance { get { return instance; } }

    private static AudioManager instance;
    private AudioSource musicPlayer;
    private int previousSelectedMusic = -1;

    private static bool isCicleMusicCoroutineRunning = false;

    void Awake()
    {
        instance = this;
        musicPlayer = this.GetComponent<AudioSource>();
    }

    public static void CicleMusic()
    {
        if (!isCicleMusicCoroutineRunning)
            instance.StartCoroutine(instance.CicleMusicCoroutine(0.5f));
    }

    public static void StartMusic()
    {
        instance.StartCoroutine(instance.StartMusicCoroutine(0.5f));
    }

    public static void StopMusic(float waitSeconds = 0.5f)
    {
        instance.StartCoroutine(instance.StopMusicCoroutine(waitSeconds));
    }

    public static void PlaySoundClip(AudioClip clip)
    {
        Instance.musicPlayer.PlayOneShot(clip, 1);
    }

    private IEnumerator StopMusicCoroutine(float waitSeconds)
    {
        iTween.AudioTo(musicPlayer.gameObject, 0, musicPlayer.pitch, waitSeconds);
        yield return new WaitForSeconds(waitSeconds);
        musicPlayer.Stop();
    }

    IEnumerator StartMusicCoroutine(float waitSeconds)
    {
        if (!musicPlayer.isPlaying)
        {
            musicPlayer.Stop();
            musicPlayer.volume = 0;
            musicPlayer.PlayDelayed(waitSeconds);

            yield return new WaitForSeconds(waitSeconds);

            musicPlayer.volume = 1;
        }
    }

    IEnumerator CicleMusicCoroutine(float waitSeconds)
    {
        isCicleMusicCoroutineRunning = true;
        if (scenesMusics.Length > 0)
        {
            if (!musicPlayer.isPlaying)
            {
                StopMusic(0.5f);

                yield return new WaitForSeconds(0.5f);

                int newMusicIndex = -1;
                int i = 0;
                do
                {
                    i++;
                    newMusicIndex = UnityEngine.Random.Range(0, scenesMusics.Length);
                    if (i == 10000)
                        break;
                } while (newMusicIndex == previousSelectedMusic);

                previousSelectedMusic = newMusicIndex;
                musicPlayer.clip = scenesMusics[newMusicIndex];
                musicPlayer.PlayDelayed(waitSeconds);

                yield return new WaitForSeconds(waitSeconds);

                musicPlayer.volume = 1;
            }
        }
        else
            StopMusic();

        isCicleMusicCoroutineRunning = false;
    }
}
