﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using UnityEngine.UI;

public class GameManager : MonoBehaviour
{
    public GameObject[] actsContainer;
    public Transform rightCurtain;
    public Transform leftCurtain;

    public static List<GameObject> ActsContainer { get; private set; }

    public static GameManager Instance { get; set; }
    private GameObject character;

    public enum GameAct { ACT1, ACT2, ACT3, EPILOGUE }

    void Start()
    {
        Instance = this;
        ActsContainer = new List<GameObject>();
        leftCurtain.GetComponent<Animator>().Stop();
        rightCurtain.GetComponent<Animator>().Stop();

        foreach (GameObject actContainer in actsContainer)
        {
            ActsContainer.Add(actContainer);
            actContainer.SetActive(false);
        }

        EventsManager.InitEvents();
        ChangeScene(GameAct.ACT1);
        StartCoroutine(ResetForeground());
    }

    void Update()
    {
        AudioManager.CicleMusic();
    }

    public void OpenCurtains()
    {
        leftCurtain.gameObject.SetActive(false);
        rightCurtain.gameObject.SetActive(false);
        leftCurtain.gameObject.SetActive(true);
        rightCurtain.gameObject.SetActive(true);
        leftCurtain.GetComponent<Animator>().Play("leftCurtainOpen");
        rightCurtain.GetComponent<Animator>().Play("rightCurtainOpen");
    }

    public void CloseCurtains()
    {
        leftCurtain.GetComponent<Animator>().Play("leftCurtainClose");
        rightCurtain.GetComponent<Animator>().Play("rightCurtainClose");
    }

    IEnumerator ResetForeground()
    {
        yield return new WaitForEndOfFrame();

        leftCurtain.position = new Vector3(-0.6f, 0, 0);
        rightCurtain.position = new Vector3(0.6f, 0, 0);
    }

    public void ChangeScene(GameAct scene)
    {
        switch (scene)
        {
            case GameAct.ACT1:
                LoadAct1();
                break;
            case GameAct.ACT2:
                LoadAct2();
                break;
            case GameAct.ACT3:
                LoadAct3();
                break;
            case GameAct.EPILOGUE:
                LoadEpilogue();
                break;
            default:
                break;
        }
    }

    private void LoadAct1()
    {
        actsContainer[0].SetActive(true);
        actsContainer[1].SetActive(false);
        actsContainer[2].SetActive(false);
        actsContainer[3].SetActive(false);

        StartCoroutine(LoadAct1Coroutine());
    }

    IEnumerator LoadAct1Coroutine()
    {
        yield return new WaitForSeconds(5);
        GameObject.Find("Foreground/Logo").SetActive(false);

        OpenCurtains();

        GameObject bottomText = GameObject.Find("Foreground/Papiro");
        GameObject topText = GameObject.Find("Foreground/TextTop");
        bottomText.transform.Find("TextBottom").GetComponent<SpriteRenderer>().sprite = Resources.Load<Sprite>("scena_01_sotto");
        topText.GetComponent<SpriteRenderer>().sprite = Resources.Load<Sprite>("scena_01_sopra");

        StartCoroutine(CharacterEnter("Act1Scene/Scena/character", Events.E00));

        yield return new WaitForSeconds(2);

        GameObject.Find("Act1Scene/Scena/Sphinx").transform.GetChild(0).gameObject.SetActive(true);
    }

    IEnumerator CharacterEnter(string characterPath, Events eventToActivate)
    {
        yield return new WaitForSeconds(2.5f);

        character = GameObject.Find(characterPath);

        character.GetComponent<Animator>().Play("characterWalk");
        iTween.MoveTo(character, iTween.Hash("position", new Vector3(-0.3f, -1.10f, 0), "time", 4.5f, "easetype", iTween.EaseType.linear));
        EventsManager.SetEventValue(eventToActivate, true);
    }

    private void LoadAct2()
    {
        actsContainer[0].SetActive(false);
        actsContainer[1].SetActive(true);
        OpenCurtains();

        StartCoroutine(CharacterEnter("Act2Scene/Scena/character", Events.E10));
    }

    private void LoadAct3()
    {
        actsContainer[1].SetActive(false);
        actsContainer[2].SetActive(true);
        OpenCurtains();

        StartCoroutine(CharacterEnter("Act3Scene/Scena/character", Events.E18));
        EventsManager.SetEventValue(Events.E19, true);
    }

    private void LoadEpilogue()
    {
        actsContainer[2].SetActive(false);
        actsContainer[3].SetActive(true);
        OpenCurtains();

        bool A1 = EventsManager.GetEventValue(Events.E04) && EventsManager.GetEventValue(Events.E07) && EventsManager.GetEventValue(Events.E09) ||
            EventsManager.GetEventValue(Events.E04) && EventsManager.GetEventValue(Events.E07) && EventsManager.GetEventValue(Events.E08) ||
            EventsManager.GetEventValue(Events.E05) && EventsManager.GetEventValue(Events.E07) && EventsManager.GetEventValue(Events.E09);
        bool A2 = EventsManager.GetEventValue(Events.E04) && EventsManager.GetEventValue(Events.E06) && EventsManager.GetEventValue(Events.E09) ||
            EventsManager.GetEventValue(Events.E04) && EventsManager.GetEventValue(Events.E06) && EventsManager.GetEventValue(Events.E08) ||
            EventsManager.GetEventValue(Events.E05) && EventsManager.GetEventValue(Events.E06) && EventsManager.GetEventValue(Events.E08);
        bool A3 = EventsManager.GetEventValue(Events.E05) && EventsManager.GetEventValue(Events.E07) && EventsManager.GetEventValue(Events.E08) ||
            EventsManager.GetEventValue(Events.E05) && EventsManager.GetEventValue(Events.E06) && EventsManager.GetEventValue(Events.E09);

        bool B1 = EventsManager.GetEventValue(Events.E12) && EventsManager.GetEventValue(Events.E14) && EventsManager.GetEventValue(Events.E16) ||
            EventsManager.GetEventValue(Events.E12) && EventsManager.GetEventValue(Events.E15) && EventsManager.GetEventValue(Events.E16) ||
            EventsManager.GetEventValue(Events.E13) && EventsManager.GetEventValue(Events.E14) && EventsManager.GetEventValue(Events.E16);
        bool B2 = EventsManager.GetEventValue(Events.E12) && EventsManager.GetEventValue(Events.E15) && EventsManager.GetEventValue(Events.E17) ||
            EventsManager.GetEventValue(Events.E13) && EventsManager.GetEventValue(Events.E14) && EventsManager.GetEventValue(Events.E17) ||
            EventsManager.GetEventValue(Events.E13) && EventsManager.GetEventValue(Events.E15) && EventsManager.GetEventValue(Events.E17);
        bool B3 = EventsManager.GetEventValue(Events.E12) && EventsManager.GetEventValue(Events.E14) && EventsManager.GetEventValue(Events.E17) ||
            EventsManager.GetEventValue(Events.E13) && EventsManager.GetEventValue(Events.E15) && EventsManager.GetEventValue(Events.E16);

        bool C1 = EventsManager.GetEventValue(Events.E25) && EventsManager.GetEventValue(Events.E27) ||
            EventsManager.GetEventValue(Events.E24) && EventsManager.GetEventValue(Events.E27);
        bool C2 = EventsManager.GetEventValue(Events.E25) && EventsManager.GetEventValue(Events.E28) ||
            EventsManager.GetEventValue(Events.E24) && EventsManager.GetEventValue(Events.E28);
        bool C3 = EventsManager.GetEventValue(Events.E24) && EventsManager.GetEventValue(Events.E28);

        if (A1 && B1 && C1)
        {
            GameObject.Find("EpilogueScene/Background/dea").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_viva").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/acqua").SetActive(true);
        }

        if (A2 && B1 && C1)
        {
            GameObject.Find("EpilogueScene/Background/dio").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_vivi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/acqua").SetActive(true);
        }

        if (A1 && B1 && C2)
        {
            GameObject.Find("EpilogueScene/Background/sfondo_nuvole").SetActive(true);
            GameObject.Find("EpilogueScene/Background/dea_arrabbiata").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/avvoltoi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/ragazza_morta").SetActive(true);
        }

        if (A2 && B1 && C2)
        {
            GameObject.Find("EpilogueScene/Background/dio_arrabbiato").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
        }

        if (A1 && B1 && C3)
        {
            GameObject.Find("EpilogueScene/Background/dea_arrabbiata").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/sabbia").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/avvoltoi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
        }

        if (A2 && B1 && C3)
        {
            GameObject.Find("EpilogueScene/Background/sfondo_rosso").SetActive(true);
            GameObject.Find("EpilogueScene/Background/dio_arrabbiato").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/sangue").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/avvoltoi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
        }

        if (A1 && B2 && C1)
        {
            GameObject.Find("EpilogueScene/Background/sfondo_nuvole").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/avvoltoi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/ragazza_morta").SetActive(true);
        }

        if (A2 && B2 && C1)
        {
            GameObject.Find("EpilogueScene/Scena/soldati_blu_vivi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi_morti").SetActive(true);
        }

        if (A1 && B2 && C2)
        {
            GameObject.Find("EpilogueScene/Scena/gente_viva").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/acqua").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/ragazza_viva").SetActive(true);
        }

        if (A2 && B2 && C2)
        {
            GameObject.Find("EpilogueScene/Scena/soldati_rossi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/ragazza_morta_sangue").SetActive(true);
        }

        if (A1 && B2 && C3)
        {
            GameObject.Find("EpilogueScene/Background/sfondo_nuvole").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/avvoltoi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/ragazza_morta").SetActive(true);
        }

        if (A2 && B2 && C3)
        {
            GameObject.Find("EpilogueScene/Scena/soldati_rossi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
        }

        if (A1 && B3 && C1)
        {
            GameObject.Find("EpilogueScene/Background/dio_mostro").SetActive(true);
            GameObject.Find("EpilogueScene/Background/fire").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta_sangue").SetActive(true);
        }

        if (A2 && B3 && C1)
        {
            GameObject.Find("EpilogueScene/Background/dio_mostro").SetActive(true);
            GameObject.Find("EpilogueScene/Background/fire").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi_morti").SetActive(true);
        }

        if (A1 && B3 && C2)
        {
            GameObject.Find("EpilogueScene/Background/dio_mostro").SetActive(true);
            GameObject.Find("EpilogueScene/Background/fire").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta_sangue").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/ragazza_morta_sangue").SetActive(true);
        }

        if (A2 && B3 && C2)
        {
            GameObject.Find("EpilogueScene/Background/dio_mostro").SetActive(true);
            GameObject.Find("EpilogueScene/Background/fire").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/ragazza_morta_sangue").SetActive(true);
        }

        if (A1 && B3 && C3)
        {
            GameObject.Find("EpilogueScene/Background/dio_mostro").SetActive(true);
            GameObject.Find("EpilogueScene/Background/fire").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
        }

        if (A2 && B3 && C3)
        {
            GameObject.Find("EpilogueScene/Background/dio_mostro").SetActive(true);
            GameObject.Find("EpilogueScene/Background/fire").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/ragazza_morta_sangue").SetActive(true);
        }

        if (A3 && B1 && C1)
        {
            GameObject.Find("EpilogueScene/Background/dea").SetActive(true);
            GameObject.Find("EpilogueScene/Background/dio").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_vivi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_viva").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/acqua").SetActive(true);
        }

        if (A3 && B1 && C2)
        {
            GameObject.Find("EpilogueScene/Background/dea_arrabbiata").SetActive(true);
            GameObject.Find("EpilogueScene/Background/dio_arrabbiato").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/avvoltoi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/ragazza_morta_sangue").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi").SetActive(true);
        }

        if (A3 && B1 && C3)
        {
            GameObject.Find("EpilogueScene/Background/sfondo_rosso").SetActive(true);
            GameObject.Find("EpilogueScene/Background/dea_arrabbiata").SetActive(true);
            GameObject.Find("EpilogueScene/Background/dio_arrabbiato").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/sabbia").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/avvoltoi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi").SetActive(true);
        }

        if (A3 && B2 && C1)
        {
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi").SetActive(true);
        }

        if (A3 && B2 && C2)
        {
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi").SetActive(true);
        }

        if (A3 && B2 && C3)
        {
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/ragazza_morta_sangue").SetActive(true);
        }

        if (A3 && B3 && C1)
        {
            GameObject.Find("EpilogueScene/Background/dio_mostro").SetActive(true);
            GameObject.Find("EpilogueScene/Background/fire").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
        }

        if (A3 && B3 && C2)
        {
            GameObject.Find("EpilogueScene/Background/dio_mostro").SetActive(true);
            GameObject.Find("EpilogueScene/Background/fire").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta_sangue").SetActive(true);
        }

        if (A3 && B3 && C3)
        {
            GameObject.Find("EpilogueScene/Background/sfondo_eclissi").SetActive(true);
            GameObject.Find("EpilogueScene/Background/dio_mostro").SetActive(true);
            GameObject.Find("EpilogueScene/Background/fire").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/gente_morta").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_rossi_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/soldati_blu_morti").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/sangue").SetActive(true);
            GameObject.Find("EpilogueScene/Scena/avvoltoi").SetActive(true);
        }

        StartCoroutine(EpilogueEnd());
    }

    IEnumerator EpilogueEnd()
    {
        yield return new WaitForSeconds(15);

        CloseCurtains();

        yield return new WaitForSeconds(2);

        GameObject.Find("Canvas").transform.GetChild(0).gameObject.SetActive(true);
    }
}
